@@ -2,17 +2,16 @@
 
 use lib qw(../blib/lib ../blib/arch ../blib/lib/auto ../blib/arch/auto);
 
-use File::LibMagic qw(magic_buffer magic_file magic_open magic_load mb magic_close);
+use File::LibMagic ':all';
 use Benchmark qw(timethese cmpthese);
 
 my $handle=magic_open(0);
 my $ret   =magic_load($handle,"");
 
 my $r=timethese(5000, {
-	a => sub { my $a=magic_buffer("Hi\n"); },
-	b => sub { my $a=magic_buffer("Hi\n"); },
-	c => sub { my $a=mb($handle,"Hi\n"); }
-	} );
+	a => sub { my $a=magic_buffer($handle,"Hi\n"); },
+	b => sub { my $a=MagicBuffer("Hi\n"); },
+      } );
 
 cmpthese($r);
 
